==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Kernel_23/navtreeindex9.js <==
var NAVTREEINDEX9 =
{
"index.html#Kernel_23CartesianKernels":[0,1,1],
"index.html#Kernel_23ChoosingaKernelandPredefinedKernels":[0,1,5],
"index.html#Kernel_23Constructions":[0,3,1],
"index.html#Kernel_23ConstructivePredicates":[0,3,3],
"index.html#Kernel_23Design":[0,6],
"index.html#Kernel_23GenericityThroughParameterization":[0,1,0],
"index.html#Kernel_23HomogeneousKernels":[0,1,2],
"index.html#Kernel_23Introduction":[0,4,0],
"index.html#Kernel_23Kernel":[0,2],
"index.html#Kernel_23KernelObjects":[0,2,1],
"index.html#Kernel_23KernelasaTraitsClass":[0,1,4],
"index.html#Kernel_23Limitations":[0,4,2],
"index.html#Kernel_23NamingConventions":[0,1,3],
"index.html#Kernel_23OrientationandRelativePosition":[0,2,2],
"index.html#Kernel_23PointsandVectors":[0,2,0],
"index.html#Kernel_23PredefinedKernels":[0,1,5,0],
"index.html#Kernel_23Predicates":[0,3],
"index.html#Kernel_23Predicates_1":[0,3,0],
"index.html#Kernel_23Robustness":[0,0,0],
"index.html#Kernel_23VariantReturnValues":[0,3,2],
"index.html#kernel_intro":[0,0],
"index.html#kernel_rep":[0,1],
"index.html#sectionextensiblekernel":[0,4],
"index.html#sectionprojectiontraits":[0,5],
"modules.html":[1],
"pages.html":[],
"structCGAL_1_1Ambient__dimension.html":[1,0,8,0],
"structCGAL_1_1Ambient__dimension.html#a01fc7206e5c562cf1b08b52f1a7a0063":[1,0,8,0,1],
"structCGAL_1_1Ambient__dimension.html#adf5ae4be020beaeae563a89552495bf7":[1,0,8,0,0],
"structCGAL_1_1Cartesian.html":[1,0,4,0],
"structCGAL_1_1Cartesian.html#a4669cacde64b5fe6f7a35f4844c58398":[1,0,4,0,1],
"structCGAL_1_1Cartesian.html#a8cb4bfb5620f0972f846f002db57f67e":[1,0,4,0,0],
"structCGAL_1_1Dimension__tag.html":[1,0,8,1],
"structCGAL_1_1Dimension__tag.html#a331a1ccd2e5c6b003b2efcf753b2efe6":[1,0,8,1,0],
"structCGAL_1_1Dynamic__dimension__tag.html":[1,0,8,2],
"structCGAL_1_1Feature__dimension.html":[1,0,8,3],
"structCGAL_1_1Feature__dimension.html#aa55bb82b0304952e09760c5d168fa104":[1,0,8,3,1],
"structCGAL_1_1Feature__dimension.html#acbcab3f12b823bc16fbc636a867661e8":[1,0,8,3,0],
"structCGAL_1_1Filtered__kernel.html":[1,0,4,2],
"structCGAL_1_1Filtered__kernel.html#a0203e552b521b48dd3e511e5af124a7b":[1,0,4,2,2],
"structCGAL_1_1Filtered__kernel.html#a30aad0394da1283eb3d2ac87f0aa36df":[1,0,4,2,1],
"structCGAL_1_1Filtered__kernel.html#ae72cbb94616fe734950bcbf8b087bfba":[1,0,4,2,0],
"structCGAL_1_1Filtered__kernel__adaptor.html":[1,0,4,1],
"structCGAL_1_1Homogeneous.html":[1,0,4,4],
"structCGAL_1_1Homogeneous.html#a002a92b6c4048842b3bf528f3c4bacf7":[1,0,4,4,0],
"structCGAL_1_1Homogeneous.html#a79110268c6cc705967095874abe53e6d":[1,0,4,4,1],
"structCGAL_1_1Kernel__traits.html":[1,0,4,5],
"structCGAL_1_1Kernel__traits.html#adaf2b06e17d5377307fca20b6bc2bbf9":[1,0,4,5,0],
"structCGAL_1_1Simple__cartesian.html":[1,0,4,10],
"structCGAL_1_1Simple__cartesian.html#a33d4df5a291b37d25476b6f35c1d1bf9":[1,0,4,10,1],
"structCGAL_1_1Simple__cartesian.html#a7c21b43a7da612194bd57c927f80ebc3":[1,0,4,10,0],
"structCGAL_1_1Simple__homogeneous.html":[1,0,4,11],
"structCGAL_1_1Simple__homogeneous.html#a3437428a4684ec9298cbf3b63f2fa560":[1,0,4,11,0],
"structCGAL_1_1Simple__homogeneous.html#a7cd6934f5eef128a6368f9ec3bfee0ba":[1,0,4,11,1]
};

==> CGAL-6.1-doc_html.tar.xz: doc_html/Kernel_23/navtreeindex9.js <==
var NAVTREEINDEX9 =
{
"index.html":[0],
"index.html#Kernel_23Acknowledgment":[0,6,0],
"index.html#Kernel_23AnExtensiveExample":[0,4,1],
"index.html#Kernel_23CartesianKernels":[0,1,1],
"index.html#Kernel_23ChoosingaKernelandPredefinedKernels":[0,1,5],
"index.html#Kernel_23Constructions":[0,3,1],
"index.html#Kernel_23ConstructivePredicates":[0,3,3],
"index.html#Kernel_23Design":[0,6],
"index.html#Kernel_23GenericityThroughParameterization":[0,1,0],
"index.html#Kernel_23HomogeneousKernels":[0,1,2],
"index.html#Kernel_23Introduction":[0,4,0],
"index.html#Kernel_23Kernel":[0,2],
"index.html#Kernel_23KernelObjects":[0,2,1],
"index.html#Kernel_23KernelasaTraitsClass":[0,1,4],
"index.html#Kernel_23Limitations":[0,4,2],
"index.html#Kernel_23NamingConventions":[0,1,3],
"index.html#Kernel_23OrientationandRelativePosition":[0,2,2],
"index.html#Kernel_23PointsandVectors":[0,2,0],
"index.html#Kernel_23PredefinedKernels":[0,1,5,0],
"index.html#Kernel_23Predicates":[0,3],
"index.html#Kernel_23Predicates_1":[0,3,0],
"index.html#Kernel_23Robustness":[0,0,0],
"index.html#Kernel_23VariantReturnValues":[0,3,2],
"index.html#kernel_intro":[0,0],
"index.html#kernel_rep":[0,1],
"index.html#sectionextensiblekernel":[0,4],
"index.html#sectionprojectiontraits":[0,5],
"modules.html":[1],
"pages.html":[],
"structCGAL_1_1Ambient__dimension.html":[1,0,8,0],
"structCGAL_1_1Ambient__dimension.html#a01fc7206e5c562cf1b08b52f1a7a0063":[1,0,8,0,1],
"structCGAL_1_1Ambient__dimension.html#adf5ae4be020beaeae563a89552495bf7":[1,0,8,0,0],
"structCGAL_1_1Cartesian.html":[1,0,4,0],
"structCGAL_1_1Cartesian.html#a4669cacde64b5fe6f7a35f4844c58398":[1,0,4,0,1],
"structCGAL_1_1Cartesian.html#a8cb4bfb5620f0972f846f002db57f67e":[1,0,4,0,0],
"structCGAL_1_1Dimension__tag.html":[1,0,8,1],
"structCGAL_1_1Dimension__tag.html#a331a1ccd2e5c6b003b2efcf753b2efe6":[1,0,8,1,0],
"structCGAL_1_1Dynamic__dimension__tag.html":[1,0,8,2],
"structCGAL_1_1Feature__dimension.html":[1,0,8,3],
"structCGAL_1_1Feature__dimension.html#aa55bb82b0304952e09760c5d168fa104":[1,0,8,3,1],
"structCGAL_1_1Feature__dimension.html#acbcab3f12b823bc16fbc636a867661e8":[1,0,8,3,0],
"structCGAL_1_1Filtered__kernel.html":[1,0,4,2],
"structCGAL_1_1Filtered__kernel.html#a0203e552b521b48dd3e511e5af124a7b":[1,0,4,2,2],
"structCGAL_1_1Filtered__kernel.html#a30aad0394da1283eb3d2ac87f0aa36df":[1,0,4,2,1],
"structCGAL_1_1Filtered__kernel.html#ae72cbb94616fe734950bcbf8b087bfba":[1,0,4,2,0],
"structCGAL_1_1Filtered__kernel__adaptor.html":[1,0,4,1],
"structCGAL_1_1Homogeneous.html":[1,0,4,4],
"structCGAL_1_1Homogeneous.html#a002a92b6c4048842b3bf528f3c4bacf7":[1,0,4,4,0],
"structCGAL_1_1Homogeneous.html#a79110268c6cc705967095874abe53e6d":[1,0,4,4,1],
"structCGAL_1_1Kernel__traits.html":[1,0,4,5],
"structCGAL_1_1Kernel__traits.html#adaf2b06e17d5377307fca20b6bc2bbf9":[1,0,4,5,0],
"structCGAL_1_1Simple__cartesian.html":[1,0,4,10],
"structCGAL_1_1Simple__cartesian.html#a33d4df5a291b37d25476b6f35c1d1bf9":[1,0,4,10,1],
"structCGAL_1_1Simple__cartesian.html#a7c21b43a7da612194bd57c927f80ebc3":[1,0,4,10,0],
"structCGAL_1_1Simple__homogeneous.html":[1,0,4,11],
"structCGAL_1_1Simple__homogeneous.html#a3437428a4684ec9298cbf3b63f2fa560":[1,0,4,11,0],
"structCGAL_1_1Simple__homogeneous.html#a7cd6934f5eef128a6368f9ec3bfee0ba":[1,0,4,11,1]
};
